@@ -47,29 +47,27 @@ Window_Test::Window_Test()
 
   m_refClient->add_dir(m_strMainDir);
 
-  // test code to figure out why lists aren't working:
+  // test code to figure out show that list of floats work:
   /*
-  std::list<Glib::ustring> testListStr;
-  testListStr.push_back("blah");
-  testListStr.push_back("asdf");
-  testListStr.push_back("foobar");
+  Glib::ustring testkey = m_strMainDir + "/test_floattype_list";
+  typedef gdouble floattype;
 
-  m_refClient->set_string_list(m_strMainDir + "/test_string_list", testListStr);
+  std::list<floattype> testListFloat;
+  testListFloat.push_back(1.1);
+  testListFloat.push_back(2.2);
+  testListFloat.push_back(3.3);
+  m_refClient->set_float_list(testkey, testListFloat);
 
-  std::list<int> testListInt;
-  testListInt.push_back(1);
-  testListInt.push_back(2);
-  testListInt.push_back(3);
-
-  m_refClient->set_int_list(m_strMainDir + "/test_int_list", testListInt);
-
-  std::list<int> testListIntFromGet = m_refClient->get_int_list(m_strMainDir + "/test_int_list");
-  for(std::list<int>::iterator iter = testListIntFromGet.begin(); iter != testListIntFromGet.end(); ++iter)
+  std::list<floattype> testListFloatFromGet = m_refClient->get_float_list(testkey);
+  for(std::list<floattype>::iterator iter = testListFloatFromGet.begin(); iter != testListFloatFromGet.end(); ++iter)
   {
-    int a = *iter;
-    g_warning("%d", a);
+    floattype a = *iter;
+    //std::cout << "float list item:" << a << std::endl;
+    g_warning("floattype list item: %f", a);
   }
   */
+ 
+  
 
   add(m_VBox);
 
